"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const typescript_1 = require("typescript");
/**
 * Format the path to posix.
 *
 * @param path - The path to format.
 * @returns The formatted path.
 */
function formatPath(path) {
    return path.replace(/\\/g, '/');
}
/**
 * Analyze a source file, check if it should be modified.
 */
class FileAnalyzer {
    constructor(context) {
        this.context = context;
    }
    wants(node) {
        return ((0, typescript_1.isSourceFile)(node) &&
            this.context.autoRequires.some(autoRequire => formatPath((0, path_1.relative)(this.context.basePath, node.fileName)) === formatPath(autoRequire.file)));
    }
    visit(node) {
        this.context.autoRequires
            // Remove configurations not for this file
            .filter(autoRequire => formatPath((0, path_1.relative)(this.context.basePath, node.fileName)) === formatPath(autoRequire.file))
            .forEach(configuration => {
            if (!(configuration.variable in this.context.detectedFiles)) {
                this.context.detectedFiles[configuration.variable] = {};
            }
            const currentDir = (0, path_1.dirname)(node.fileName);
            configuration.foundFiles
                // Re-create the full path…
                .map(filename => (0, path_1.resolve)(this.context.basePath, filename))
                // …and get a path relative to current file.
                .map(filename => (0, path_1.relative)(currentDir, filename))
                // Manage extension, if any
                .map(filename => {
                const baseFilename = filename.slice(0, -(0, path_1.extname)(filename).length);
                const extension = filename.slice(baseFilename.length + 1);
                if (configuration.codeExtensions.includes(extension)) {
                    return [baseFilename, true];
                }
                else {
                    return [filename, false];
                }
            })
                .forEach(([filename, sourceCode]) => {
                this.context.detectedFiles[configuration.variable][filename] = {
                    filePath: filename.startsWith('.') ? filename : '.' + path_1.sep + filename,
                    sourceCode,
                };
            });
        });
        return [node];
    }
}
exports.default = FileAnalyzer;
//# sourceMappingURL=FileAnalyzer.js.map