import type { NodeVisitorContext } from 'simple-ts-transform';
import type { NodeFactory, Program, TransformationContext } from 'typescript';
/**
 * The configuration as expected from user.
 */
interface Configuration {
    /**
     * Where to read sources.
     */
    source: {
        /**
         * The glob expression to select files.
         */
        glob: string;
        /**
         * An optional file or list of files to ignore.
         */
        ignore?: string | string[];
    };
    /**
     * Treatment on target.
     */
    target: {
        /**
         * The name of the file in which modifications must be done.
         */
        file: string;
        /**
         * The name of the variable to update in the file.
         */
        variable: string;
        /**
         * Extensions of files to be considered source code.
         */
        codeExtensions?: string[];
    };
}
/**
 * An auto-require element.
 */
declare type AutoRequire = Required<Configuration['target']> & {
    /**
     * The files matching the provided glob.
     */
    foundFiles: string[];
};
/**
 * Context for the transformer.
 */
export default class TContext implements NodeVisitorContext {
    /**
     * The node factory.
     */
    private currentFactory;
    /**
     * The base path for the compilation.
     */
    readonly basePath: string;
    /**
     * All the configuration elements.
     */
    readonly autoRequires: AutoRequire[];
    /**
     * The detected files.
     */
    detectedFiles: {
        [variable: string]: {
            [name: string]: {
                filePath: string;
                sourceCode: boolean;
            };
        };
    };
    /**
     * Create the context.
     *
     * @param program - The program object.
     * @param configuration - The provided configuration.
     */
    constructor(program: Program, configuration: unknown);
    initNewFile(context: TransformationContext): void;
    /**
     * @returns The node factory.
     */
    get factory(): NodeFactory;
}
export {};
